===========================================
Practical Things to do with a Microcomputer
===========================================

.. image:: cover.jpg

`Download the original book <https://drive.google.com/open?id=0Bxv0SsvibDMTbTdNd1Z6YnN5NG8>`__

